#yelow #short {
  color: #fea;
}
#yelow #long {
  color: #ffeeaa;
}
#yelow #rgba {
  color: rgba(255, 238, 170, 0.1);
}
#yelow #argb {
  color: #1affeeaa;
}
#blue #short {
  color: #00f;
}
#blue #long {
  color: #0000ff;
}
#blue #rgba {
  color: rgba(0, 0, 255, 0.1);
}
#blue #argb {
  color: #1a0000ff;
}
#alpha #hsla {
  color: hsla(11, 20%, 20%, 0.6);
}
#overflow .a {
  color: #000000;
}
#overflow .b {
  color: #ffffff;
}
#overflow .c {
  color: #ffffff;
}
#overflow .d {
  color: #00ff00;
}
#overflow .e {
  color: rgba(0, 31, 255, 0.42);
}
#grey {
  color: #c8c8c8;
}
#333333 {
  color: #333333;
}
#808080 {
  color: hsl(0, 0%, 50%);
}
#00ff00 {
  color: hsl(120, 100%, 50%);
}
.lightenblue {
  color: #3333ff;
}
.darkenblue {
  color: #0000cc;
}
.unknowncolors {
  color: blue2;
  border: 2px solid superred;
}
.transparent {
  color: transparent;
  background-color: rgba(0, 0, 0, 0);
}
#alpha #fromvar {
  opacity: 0.7;
}
#alpha #short {
  opacity: 1;
}
#alpha #long {
  opacity: 1;
}
#alpha #rgba {
  opacity: 0.2;
}
#alpha #hsl {
  opacity: 1;
}
#percentage {
  color: 255;
  border-color: rgba(255, 0, 0, 0.5);
}
#rrggbbaa {
  test-1: #55FF5599;
  test-2: #5F59;
  test-3: rgba(136, 255, 136, 0.6);
  test-4: rgba(85, 255, 85, 0.1);
  test-5: rgba(85, 255, 85, 0.6);
  test-6: rgba(85, 255, 85, 0.6);
  test-7: rgba(85, 255, 85, 0.5);
  test-8: rgba(var(--color-accent), 0.2);
  test-9: rgb(var(--color-accent));
  test-9: hsla(var(--color-accent));
  test-10: #55FF5599;
  test-11: hsla(120, 100%, 66.66666667%, 0.6);
  test-12: hsla(120, 100%, 66.66666667%, 0.5);
  --semi-transparent-dark-background: #001e00ee;
  --semi-transparent-dark-background-2: #001e00;
}
