.units {
  font: 1.2rem/2rem;
  font: 8vw/9vw;
  font: 10vh/12vh;
  font: 12vm/15vm;
  font: 12vmin/15vmin;
  font: 1.2ch/1.5ch;
}
.math {
  a: 2;
  b: 2px / 2;
  c: 1px;
  d: 1px;
  e: 4px / 2;
  f: 2px;
}
