.parens {
  border: 2px solid black;
  margin: 1px 3px 16 3;
  width: 36;
  padding: 2px 36px;
}
.more-parens {
  padding: 8 4 4 4px;
  width-all: 96;
  width-first: 96;
  width-keep: 96;
  height: calc(100% + (25vh - 20px));
  height-keep: 113;
  height-all: 113;
  height-parts: 113;
  margin-keep: 12;
  margin-parts: 12;
  margin-all: 12;
  border-radius-keep: 8px / 4 + 3px;
  border-radius-parts: 8px / 7px;
  border-radius-all: 5px;
}
.negative {
  neg-var: -1;
  neg-var-paren: -1;
}
.nested-parens {
  width: 71;
  height: 6;
}
.mixed-units {
  margin: 2px 4em 1 5pc;
  padding: 6px 1em 2px 2;
}
.test-rule-false-negatives {
  a: (;
}
