.theOnlySelector {
  avoid: warning;
}
.unusedAndReference:extend(.theOnlySelector) {
    unused-and: reference;
}

@import (reference) "global-scope-nested.less";

.test-rule-b {
  background-color: green;
  &:extend(.test-rule-a all);
}
