input[type="text"].class#id[attr=32]:not(1) {
  color: inherit;
}
div#id.class[a=1][b=2].class:not(1) {
  color: inherit;
}
@media print {
  .class {
    color: blue;
  }
  .class .sub {
    width: 42;
  }
}
.visible {
  color: red;
}
.visible .c {
  color: green;
}
.visible {
  color: green;
}
.visible:hover {
  color: green;
}
.only-with-visible + .visible,
.visible + .only-with-visible,
.visible + .visible {
  color: green;
}
.only-with-visible + .visible .sub,
.visible + .only-with-visible .sub,
.visible + .visible .sub {
  color: green;
}
@supports (something: else) {
  .class {
    something: else;
  }
  .nestedToo .class {
    something: else;
  }
}
.b {
  color: red;
  color: green;
}
.b .c {
  color: green;
}
.b:hover {
  color: green;
}
.b + .b {
  color: green;
}
.b + .b .sub {
  color: green;
}
.y {
  pulled-in: yes /* inline comment survives */;
}
/* comment pulled in */
.visible {
  extend: test;
}
.test-rule-mediaq-import {
  color: green;
  test: 340px;
}
@media (max-size: 450px) {
  .test-rule-mediaq-import {
    color: red;
  }
}
.test-rule {
  color: red;
}
.test-rule:first-child {
  color: blue;
}
@keyframes some-name {
  property: value;
}
@supports (animation-name: test) {
  @keyframes some-name {
    property: value;
  }
  .selector {
    color: red;
  }
}
div {
  this isn't very valid CSS.
}
this isn't very valid CSS.
