@charset "UTF-8";
/* line 1, {pathimport}test.less */
/* @charset "ISO-8859-1"; */
/* line 23, {pathimport}test.less */
.tst3 {
  color: grey;
}
/* line 15, {path}linenumbers.less */
.test-rule1 {
  color: black;
}
/* line 6, {path}linenumbers.less */
.test-rule2 {
  color: red;
}
@media all {
  /* line 5, {pathimport}test.less */
  .tst {
    color: black;
  }
}
@media all and screen {
  /* line 7, {pathimport}test.less */
  .tst {
    color: red;
  }
  /* line 9, {pathimport}test.less */
  .tst .tst3 {
    color: inherit;
  }
}
/* line 18, {pathimport}test.less */
.tst2 {
  color: inherit;
}
/* line 27, {path}linenumbers.less */
.test-rule {
  color: red;
  width: 2;
}
