@import url("import/import-test-c.less");// import inline should not float above this #1954
@import (inline) url("import/import-test-d.css") (min-width:600px);
@import (inline, css) url("import/invalid-css.less");