.my-navbar {
  background: rebeccapurple;
  val: output;
}
.another-navbar {
  background: rebeccapurple !important;
  border: 1px solid lightblue !important;
}
.another {
  background: black;
  border: 1px solid grey;
}
